<template>
  <div class="content">
    <el-row :gutter="20">
      <el-col :span="12">
        <el-card shadow="never">
          <div slot="header" class="clearfix">
            <span class="font-18 font-bold">待办名称</span>
          </div>
          <div class="f-r f-r-between m-b-10">
            <el-radio-group v-model="waitType" size="medium">
              <el-radio-button label="1">全部</el-radio-button>
            </el-radio-group>
            <div class="to-more" @click="nav('/stock/transfer/transferissue')">查看更多 ></div>
          </div>
          <el-table :data="waitWorkData" class="top-tb" :show-header="false" size="medium">
            <el-table-column prop="number" align="center"></el-table-column>
            <el-table-column prop="type" align="center" width="100"></el-table-column>
            <el-table-column prop="orgName" align="center" width="100"></el-table-column>
            <el-table-column prop="name" align="center" width="80"></el-table-column>
            <el-table-column prop="createTime" align="center" width="180">
              <template slot-scope="scope">
                <span class="font-14 color-333">{{ formattTime(scope.row.createTime) }}</span>
              </template>
            </el-table-column>
            <el-table-column prop="date" label="操作" align="center" width="120">
              <template slot-scope="scope">
                <el-button @click.native.prevent="aduitThis(scope.row.id)" size="small" type="primary">处理</el-button>
              </template>
            </el-table-column>
          </el-table>
        </el-card>
      </el-col>
      <el-col :span="12">
        <el-card shadow="never">
          <div slot="header" class="clearfix">
            <span class="font-18 font-bold">预警通知</span>
          </div>
          <div class="f-r f-r-between m-b-10">
            <el-radio-group  size="medium" v-model="earlyWarningType" @change="changeEarlyWarning">
              <el-radio-button label="1">全部</el-radio-button>
              <el-radio-button label="2">缺货（12）</el-radio-button>
              <el-radio-button label="3">超出（3）</el-radio-button>
            </el-radio-group>
            <div class="to-more" @click="nav('/stock/ledger/alertQuery')">查看更多 ></div>
          </div>
          <el-table :data="earlyWarningData" class="top-tb" :show-header="false" size="medium">
            <el-table-column prop="type" align="center"></el-table-column>
            <el-table-column prop="name" align="center" width="100"></el-table-column>
            <el-table-column prop="orgName" align="center" width="100"></el-table-column>
            <el-table-column prop="surplus" align="center" width="100">
              <template slot-scope="scope">
                <span class="font-14 color-333">剩余{{ scope.row.surplus }}套</span>
              </template>
            </el-table-column>
            <el-table-column prop="createTime" align="center" width="180">
              <template slot-scope="scope">
                <span class="font-14 color-333">{{ formattTime(scope.row.createTime) }}</span>
              </template>
            </el-table-column>
            <el-table-column prop="date" label="操作" align="center" width="120">
              <template slot-scope="scope">
                <el-button @click.native.prevent="aduitThis(scope.row.id)" size="small" type="primary">处理</el-button>
              </template>
            </el-table-column>
          </el-table>
        </el-card>
      </el-col>
    </el-row>
    <!-- 中间统计部分-->
    <div class="f-r f-r-between total-list">
      <div class="total-item">
        <div class="font-14 color-666">物品数量</div>
        <div class="font-14 color-333" style="margin-top:6px;"><span class="total-num">1200</span></div>
      </div>
      <div class="total-item">
        <div class="font-14 color-666">资产总金额</div>
        <div class="font-14 color-333" style="margin-top:6px;"><span class="total-num">120.88</span>万元</div>
      </div>
      <div class="total-item">
        <div class="font-14 color-666">物品占用率</div>
        <div class="font-14 color-333" style="margin-top:6px;"><span class="total-num">80%</span></div>
      </div>
      <div class="total-item">
        <div class="font-14 color-666">A类物品数量</div>
        <div class="font-14 color-333" style="margin-top:6px;"><span class="total-num">120</span></div>
      </div>
      <div class="total-item">
        <div class="font-14 color-666">B类物品数量</div>
        <div class="font-14 color-333" style="margin-top:6px;"><span class="total-num">123</span></div>
      </div>
    </div>
  <!-- 类别金额统计/类别数量统计 -->
    <el-row :gutter="20">
      <el-col :span="12">
        <LBSLTJ></LBSLTJ>
      </el-col>
      <el-col :span="12">
        <LBJETJ></LBJETJ>
      </el-col>
    </el-row>
  <!--  资产增长/报废统计图（数量）-->
    <XYZC></XYZC>
  </div>
</template>

<script>
// 创建Context
import {LongToDateTime} from "@/utils/DateFormatter";

const ComponentContext = require.context('./components', false, /\.vue$/i);
let res_components = {};
// 生成待待注册组件集合
ComponentContext.keys().forEach((componentFilePath) => {
  let comp = ComponentContext(componentFilePath);
  res_components[componentFilePath.replace(/^\.\/(.*)\.\w+$/, '$1')] = comp.default;
});
export default {
  name: 'Dashboard',
  components: {...res_components},
  data() {
    return {
      waitType: '1',
      waitWorkData: [
        {number: 'SJQ12345', type: '物品申领', orgName: '金融业务部', name: '张三丰', createTime: 20231127150606, id: 1},
        {number: 'SJQ12345', type: '物品申领', orgName: '金融业务部', name: '张三丰', createTime: 20231127150606, id: 2},
        {number: 'SJQ12345', type: '物品申领', orgName: '金融业务部', name: '张三丰', createTime: 20231127150606, id: 3},
        {number: 'SJQ12345', type: '物品申领', orgName: '金融业务部', name: '张三丰', createTime: 20231127150606, id: 4},
        {number: 'SJQ12345', type: '物品申领', orgName: '金融业务部', name: '张三丰', createTime: 20231127150606, id: 5},
      ], // 待办工作
      earlyWarningType: '1',
      earlyWarningData: [
        {type: '施乐复印机碳粉', name: '施乐c2201', surplus: 4, createTime: 20231127150606, id: 1},
        {type: '施乐复印机碳粉', name: '施乐c2201', surplus: 5, createTime: 20231127150606, id: 2},
        {type: '施乐复印机碳粉', name: '施乐c2201', surplus: 6, createTime: 20231127150606, id: 3},
        {type: '施乐复印机碳粉', name: '施乐c2201', surplus: 6, createTime: 20231127150606, id: 4},
      ] // 预警通知
    };
  },
  created() {

  },
  methods: {
    // 格式化时间
    formattTime(time) {
      return LongToDateTime(time)
    },
    // 获取预警通知列表数据
    getAduitList() {
      let form = {
        pageSize: 5,
        pageNum: 1,
        waitType: this.waitType
      }
    },
    // 处理待办工作
    aduitThis(id) {
    },
    // 切换预警通知
    changeEarlyWarning(e) {
      this.earlyWarningType = e
      this.$nextTick(() => {
        this.getWarningList()
      })
    },
    // 获取预警通知列表数据
    getWarningList() {
      let form = {
        pageSize: 5,
        pageNum: 1,
        earlyWarningType: this.earlyWarningType
      }
    },
  //  跳转
    nav(url){
      this.$router.push(url)
    }
  }

};
</script>
<style lang="scss" scoped>
.content {
  padding: 10px
}

.to-more {
  font-size: 14px;
  color: #0d997c;
  cursor: pointer;
}

.m-b-10 {
  margin-bottom: 10px;
}

.top-tb {
  width: 100%;
}
>>>.el-table__body{
  min-height: 265px;
}
.total-list {
  padding: 15px 0;
}

.total-item {
  width: 19%;
  padding: 12px 20px;
  border-radius: 8px;
  margin-right: 1%;
  background-color: #FFFFFF;
}

.total-item:last-child {
  margin: 0;
}

.total-num {
  font-size: 24px;
  font-weight: bold;
  margin-right: 3px;
}
</style>
